pub struct ChannelMessagesView { /* private fields */ }Expand description
A collection of interfaces for endpoint-specific Discord objects. A view for managing a channel’s messages.
Implementations
Sourceimpl ChannelMessagesView
impl ChannelMessagesView
Sourcepub fn get_all(&self) -> impl Future<Item = Vec<Message>, Error = Error>
pub fn get_all(&self) -> impl Future<Item = Vec<Message>, Error = Error>
Fetches all messages in this channel.
Sourcepub fn get(&self, mid: &Snowflake) -> impl Future<Item = Message, Error = Error>
pub fn get(&self, mid: &Snowflake) -> impl Future<Item = Message, Error = Error>
Gets a single message in this channel, with the provided ID.
Sourcepub fn delete(
&self,
mid: Snowflake,
) -> impl Future<Item = Message, Error = Error>
pub fn delete( &self, mid: Snowflake, ) -> impl Future<Item = Message, Error = Error>
Deletes a message from this channel.
Sourcepub fn bulk_delete(
&self,
ids: Vec<Snowflake>,
) -> impl Future<Item = (), Error = Error>
pub fn bulk_delete( &self, ids: Vec<Snowflake>, ) -> impl Future<Item = (), Error = Error>
Deletes multiple messages in one request for a single channel.
Sourcepub fn reactions(&self, mid: Snowflake) -> ChannelMessageReactionsView
pub fn reactions(&self, mid: Snowflake) -> ChannelMessageReactionsView
A view for managing a message’s reactions.